@@ -212,6 +212,39 @@ class Samples:
         else:
             return "<Samples object: __empty__>"
 
+    def subsample(self,
+                  item):
+        """
+        Method to get index locations as a sample object
+        :param item: list, tuple, numpy array or integer of index locations
+        :returns: Sample object
+        """
+        if isinstance(item, list) or \
+                isinstance(item, tuple) or \
+                isinstance(item, np.ndarray) or \
+                isinstance(item, int):
+
+            outsamp = Samples()
+            outsamp.x_name = self.x_name
+            outsamp.y_name = self.y_name
+
+            if isinstance(item, int):
+                item = np.array([item])
+            else:
+                item = np.array(item)
+
+            outsamp.x = self.x[np.array(item), :]
+            outsamp.y = self.y[np.array(item)]
+
+            outsamp.nsamp = outsamp.x.shape[0]
+            outsamp.index = np.arange(0, outsamp.nsamp)
+            outsamp.nfeat = outsamp.x.shape[1]
+
+            return outsamp
+
+        else:
+            raise TypeError("subsample() method works for list, tuple, numpy array or integer data types only")
+
     def format_data(self):
         """
         Method to format the samples to the RF model fit method
